export { AIGatewayService, buildAIGatewayCompletionParams, type AIGatewayChatCompletion, type AIGatewayChatCompletionParams, type AIGatewayChatMessage, type AIGatewayCompletionAdapterRequest, type AIGatewayModel, type AIGatewayModelProvider, type AIGatewayModels, type AIGatewayModelsResponse, type AIGatewayPricing, type AIGatewayRequestOptions, type AIGatewayRequestResponse, type AIGatewayReasoning, type AIGatewayResponseMetadata, type AIGatewayStreamingCompletion, AIGatewayChatCompletionParamsSchema, AIGatewayChatCompletionSchema, AIGatewayChatMessageSchema, AIGatewayModelProviderSchema, AIGatewayModelSchema, AIGatewayModelsResponseSchema, AIGatewayModelsSchema, AIGatewayPricingSchema, } from '@agentuity/core/aigateway';
import { type AIGatewayChatCompletion, type AIGatewayChatCompletionParams, type AIGatewayModels, type AIGatewayRequestOptions, type AIGatewayRequestResponse, type AIGatewayStreamingCompletion } from '@agentuity/core/aigateway';
import { type Logger } from '@agentuity/core';
import { z } from 'zod';
export declare const AIGatewayClientOptionsSchema: z.ZodObject<{
    apiKey: z.ZodOptional<z.ZodString>;
    url: z.ZodOptional<z.ZodString>;
    orgId: z.ZodOptional<z.ZodString>;
    logger: z.ZodOptional<z.ZodCustom<Logger, Logger>>;
}, z.core.$strip>;
export type AIGatewayClientOptions = z.infer<typeof AIGatewayClientOptionsSchema>;
export declare class AIGatewayClient {
    #private;
    constructor(options?: AIGatewayClientOptions);
    listModels(): Promise<AIGatewayModels>;
    complete(params: AIGatewayChatCompletionParams): Promise<AIGatewayChatCompletion>;
    request<T = unknown>(options: AIGatewayRequestOptions): Promise<AIGatewayRequestResponse<T>>;
    streamRequest(options: AIGatewayRequestOptions): Promise<AIGatewayStreamingCompletion>;
}
//# sourceMappingURL=index.d.ts.map